@@ -805,7 +805,7 @@ class Sf:
         profile_metadata
         user_profile_id = transform_sf_result_set_rec(self.sf.query_all(f"Select Id, ProfileId FROM User WHERE Username = '{username}'")['records'])
         if len(profile_metadata[profile_metadata['id'] == user_profile_id['User.ProfileId'].values[0]]['fullName']) == 0:
-            raise Exception("User does not have a retrievable / valid profile")
+            raise Exception(f"User {username} does not have a retrievable / valid profile")
         else:
             user_profile = profile_metadata[profile_metadata['id'] == user_profile_id['User.ProfileId'].values[0]]['fullName'].values[0]
 
@@ -1223,14 +1223,20 @@ class Sf:
 
 
         for profile in profiles:
-                profile_metadata_dict["System Administrator" if profile == 'Admin' else profile] = pd.DataFrame(task_result_list[profiles.index(profile)]['fieldPermissions'][0])
+                profile_result = task_result_list[profiles.index(profile)]
+                if 'fieldPermissions' in profile_result:
+                        profile_metadata_dict["System Administrator" if profile == 'Admin' else profile] = pd.DataFrame(task_result_list[profiles.index(profile)]['fieldPermissions'][0])
+                else:
+                        profile_metadata_dict["System Administrator" if profile == 'Admin' else profile] = pd.DataFrame()
     
         data = data.merge(relevant_ps_and_profiles, left_on='PermissionSet.Id', right_on='FieldPermissions.ParentId', how='left').copy()
+        
         if (len(data) > 0):
-                
-                profile_violations = data[data['PermissionSet.IsOwnedByProfile']== True][['User.Username', 'Profile.Name']].drop_duplicates().copy()
-                # profile_violations = data[data['PermissionSet.IsOwnedByProfile']== True][['User.Username', 'Profile.Name','Field API Name']]
-                profile_metadata_pd = pd.concat(profile_metadata_dict.values(), keys=profile_metadata_dict.keys(), names=['Profile', 'Index']).reset_index(level=1, drop=True).reset_index()
+            profile_violations = data[data['PermissionSet.IsOwnedByProfile']== True][['User.Username', 'Profile.Name']].drop_duplicates().copy()
+            # profile_violations = data[data['PermissionSet.IsOwnedByProfile']== True][['User.Username', 'Profile.Name','Field API Name']]
+            profile_metadata_pd = pd.concat(profile_metadata_dict.values(), keys=profile_metadata_dict.keys(), names=['Profile', 'Index']).reset_index(level=1, drop=True).reset_index()
+            
+            if len(profile_metadata_pd) > 0:
                 profile_metadata_pd.rename(columns={'Profile': 'Profile.Name'}, inplace=True)
                 profile_metadata_pd['Field API Name'] = profile_metadata_pd['field'].str.split('.').str[1]
                 profile_metadata_pd['Object API Name'] = profile_metadata_pd['field'].str.split('.').str[0]
@@ -1264,6 +1270,8 @@ class Sf:
                 ps_fls_final.columns = ['UserName','Permission Set','Object API Name','Field API Name', 'Permission']
                 
                 return pd.merge(profile_fls_final, ps_fls_final, on=['UserName','Object API Name', 'Field API Name','Permission'], how='outer')
+            else:
+                return pd.DataFrame(columns=['UserName', 'Profile', 'Field API Name', 'Object API Name','Permission', 'Permission Set'])
         else:
                 return pd.DataFrame(columns=['UserName', 'Profile', 'Field API Name', 'Object API Name','Permission', 'Permission Set'])
             
